*! version 1.0.4  03oct2006
program svy__xmpl
	version 9

	local sub : word 1 of `0'
	if substr(`"`0'"',1,2) != "Ex" {
		di as err `"`sub': subroutine not recognized"'
		exit 199
	}
	set more off
	capture noisily `0'
	if c(rc) & c(rc) != 1 {
		di as err `"problem with subroutine `sub'"'
		exit c(rc)
	}
end

// subroutines **************************************************************

program Echo
	display as input `"{p 0 4 2}`0'{p_end}"'
end

program BreakExec
	di
	Echo . `0'
	local cmd : subinstr local 0 "{break}" "", all
	`cmd'
end

program Exec
	di
	Echo . `0'
	`0'
end

program UseData
	syntax anything(name=fn id="filename") [, mem(string) ]
	drop _all
	if `"`mem'"' != "" {
		discard
		Exec quietly set mem `mem'
	}
	if !strpos(`"`fn'"',".") {
		local ext .dta
	}
	capture findfile `fn'`ext'
	if !c(rc) {
		if substr("`r(fn)'",1,1) == "." {
			Exec use `fn'
		}
		else	Exec sysuse `fn'
	}
	else {
		Exec webuse `fn'
		quietly save `fn'
	}
end

program More
	if ("$JSP_nomore" != "") exit
	set more on
	more
end

// examples *****************************************************************

program ExSvyProp
	di
	Echo *** Second National Health and Nutrition Examination Survey
	UseData nhanes2, mem(5m)
	Exec proportion agegrp
	More
	Exec svy: proportion agegrp
end

program ExSvyset1
	di
	Echo *** SRS design
	UseData auto
	Exec svyset _n
	More
	di
	Echo *** National Maternal and Infant Health Survey
	UseData nmihs, mem(2m)
	Exec svyset [pw=finwgt], strata(stratan)
	More
	di
	Echo *** Single-stage design with all the characteristics
	UseData fpc
	Exec svyset psuid [pw=weight], strata(stratid) fpc(Nh)
end

program ExSvyset2
	di
	UseData seniors
	local cmd "svyset county [pw=sampwgt], strata(state) fpc(ncounties)"
	local cmd "`cmd'{break}|| school, fpc(nschools)"
	local cmd "`cmd'{break}|| _n, strata(gender) fpc(nseniors)"
	BreakExec `cmd'
end

program ExSvyset3
	di
	Echo *** Cat and dog data from Levy and Lemeshow (1999)
	UseData poststrata
	Exec bysort type: sum totexp
	More
	Exec svyset [pw=weight], poststrata(type) postweight(postwgt) fpc(fpc)
	Exec svy: mean totexp
	More
	Exec svyset _n [pw=weight]
	Exec svy: mean totexp
end

program ExSvydes
	di
	Echo *** Second National Health and Nutrition Examination Survey
	UseData nhanes2, mem(5m)
	Exec svydes
	More
	di
	Echo *** Mean high density lipids (mg/dL)
	Exec svy: mean hdresult
	More
	di
	Echo *** Restrict to the estimation sample
	Exec svydes if e(sample), single
	More
	di
	Echo *** Specifying variables for more information
	Exec svydes hdresult, single
end

program ExCertain
	di
	Echo *** Second National Health and Nutrition Examination Survey
	UseData nhanes2, mem(5m)
	keep if !missing(hdresult)
	Exec svy: mean hdresult
	Exec svydes, single gen(single)
	More
	di
	Echo *** Generate an FPC for the certainty PSUs
	Exec gen fpc = strata <= 2
	Exec svyset psu [pw=finalwgt], strata(strata) fpc(fpc)
	More
	di
	Echo *** Estimate using the new design characteristics
	Exec svy: mean hdresult
end

program ExSvyTotal
	di
	UseData seniors
	Exec svyset
	di
	Echo *** Estimate number of seniors who have smoked
	Exec svy: total smoked
	More
	di
	Echo *** Stata 8: allowing only the first stage
	Exec svyset county [pw=sampwgt], strata(state)
	Exec svy: total smoked
end

program ExSvyLogit
	di
	Echo *** Second National Health and Nutrition Examination Survey
	UseData nhanes2, mem(5m)
	Exec svyset
	More
	di
	Echo *** Model high blood pressure on some demographics
	describe highbp height weight age female
	di
	More
	Exec svy: logit highbp height weight age female
end

program ExSvyBrrLogit
	* should have the same resulting coefficients as above example
	di
	Echo *** Second National Health and Nutrition Examination Survey
	UseData nhanes2brr, mem(5m)
	Exec svyset [pw=finalwgt], vce(brr) mse brrweight(brr_*)
	More
	Exec svy: logit highbp height weight age female
end

program ExSvyJkLogit1
	* should have the same resulting coefficients as above example
	di
	Echo *** Second National Health and Nutrition Examination Survey
	UseData nhanes2, mem(5m)
	Exec svyset
	More
	Exec svy jknife, mse: logit highbp height weight age female
end

program ExSvyJkLogit2
	* should have the same resulting coefficients as above example
	di
	Echo *** Second National Health and Nutrition Examination Survey
	UseData nhanes2jknife, mem(5m)
	di
	Echo .svyset [pw=finalwgt], vce(jackknife) jkrweight(jkw_*)
	svyset
	Exec char list jkw_1[]
	More
	Exec svy, mse: logit highbp height weight age female
end

program ExSubpop
	di
	Echo *** National Maternal and Infant Health Survey
	UseData nmihs, mem(2m)
	Exec svyset [pw=finwgt], strata(stratan)
	di
	Echo *** Focus:  birthweight, mothers with high blood pressure
	Exec describe birthwgt highbp
	Exec label list hibp
	More
	di
	Echo *** Subpopulation estimation
	Exec svy, subpop(highbp) : mean birthwgt
	More
	di
	Echo *** Restricted sample estimation
	Exec svy: mean birthwgt if highbp
end

program ExEffects
	di
	Echo *** National Maternal and Infant Health Survey
	UseData nmihs, mem(2m)
	Exec svyset [pw=finwgt], strata(stratan)
	di
	Echo *** Focus:  birthweight between mothers ///
		with normal and high blood pressure
	Exec describe birthwgt highbp
	di
	More
	di
	Echo *** Labels that can also be used as Stata names
	Exec label list hibp
	Exec label define bloodpressure 0 "BPnormal" 1 "BPhigh"
	Exec label values highbp bloodpressure
	More
	Exec svy: mean birthwgt, over(highbp)
	More
	di
	Echo *** Design effects
	Exec estat effects
	More
	di
	Echo *** Misspecification effects require an extra model fit
	Exec estat effects, meff meft
	More
	di
	Echo *** Focus:  birthweight between normal and high blood pressure
	di
	Echo *** Linear combinations
	Exec lincom [birthwgt]BPnormal - [birthwgt]BPhigh
	More
	di
	Echo *** Effects for linear combinations
	Exec estat lceffects [birthwgt]BPnormal - [birthwgt]BPhigh
end

exit
